'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var joi = require('../../utils/joi.js');

const dnsResource = {
  options: {
    validate: {
      options: {
        allowUnknown: true,
        stripUnknown: true
      },
      query: joi.object().keys({
        domain: joi.string().required(),
        format: joi.string(),
        recursive: joi.boolean().default(false),
        timeout: joi.timeout()
      }).rename('r', 'recursive', {
        override: true,
        ignoreUndefined: true
      }).rename('arg', 'domain', {
        override: true,
        ignoreUndefined: true
      })
    }
  },
  async handler(request, h) {
    const {
      app: {signal},
      server: {
        app: {ipfs}
      },
      query: {domain, recursive, timeout}
    } = request;
    const path = await ipfs.dns(domain, {
      recursive,
      signal,
      timeout
    });
    return h.response({ Path: path });
  }
};

exports.dnsResource = dnsResource;
