'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var joi = require('../../utils/joi.js');

const idResource = {
  options: {
    validate: {
      options: {
        allowUnknown: true,
        stripUnknown: true
      },
      query: joi.object().keys({
        timeout: joi.timeout(),
        peerId: joi.string()
      }).rename('arg', 'peerId', {
        override: true,
        ignoreUndefined: true
      })
    }
  },
  handler: async (request, h) => {
    const {
      app: {signal},
      server: {
        app: {ipfs}
      },
      query: {timeout, peerId}
    } = request;
    const id = await ipfs.id({
      signal,
      timeout,
      peerId
    });
    return h.response({
      ID: id.id,
      PublicKey: id.publicKey,
      Addresses: id.addresses,
      AgentVersion: id.agentVersion,
      ProtocolVersion: id.protocolVersion,
      Protocols: id.protocols
    });
  }
};

exports.idResource = idResource;
